# TOMSO: Tools for Modelling Stars and their Oscillations

TOMSO is a set of Python modules for loading and saving input and
output files for and from stellar evolution and oscillation
codes.  Functions are presently implemented for the following
standard or code-specific formats:

* [FGONG] (https://www.astro.up.pt/corot/ntools/docs/CoRoT_ESTA_Files.pdf)
* [MESA](http://mesa.sourceforge.net)
* [STARS](http://www.ast.cam.ac.uk/~stars)
* [ADIPLS](http://users-phys.au.dk/jcd/adipack.n/)
* [GYRE](https://bitbucket.org/rhdtownsend/gyre/wiki/Home)

Documentation is available on
[ReadTheDocs.org](http://tomso.readthedocs.io).  Beware that the code
is *very unstable*.  Expect the API to change drastically or
completely without warning!

## Contributors
* [Warrick Ball](https://warrickball.github.io)
